<?php

namespace Drupal\coming_soon\Tests\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests that the Coming Soon interactions are working as expected.
 *
 * @group coming_soon
 */
class ComingSoonFunctionalTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['node', 'coming_soon'];

  /**
   * A simple user with 'access content' permission
   */
  private $user;

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();
    $this->user = $this->drupalCreateUser(['administer coming soon']);
  }

  /**
   * Tests that the 'admin/config/coming_soon' path returns the right content
   */
  public function testAdminPageAccessible() {
    // Login
    $this->drupalLogin($this->user);
    // Test the page is found & accessible for users with "administer coming soon" permission
    $this->drupalGet('admin/config/coming_soon');
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Tests that a user without the right permission can't manage coming soon module
   */
  public function testPermissionOnAdminPage() {
    $not_admin = $this->drupalCreateUser(array('access content'));
    // Login
    $this->drupalLogin($not_admin);
    // Test the page is found but not accessible for users without "administer coming soon" permission
    $this->drupalGet('admin/config/coming_soon');
    $this->assertSession()->statusCodeEquals(403);
  }

  /**
   * Tests that the configuration form is not submitted when required fields are
   * not set
   */
  public function testConfigurationSubmissionFails() {
    // Login
    $this->drupalLogin($this->user);
    // go to admin page
    $this->drupalGet('admin/config/coming_soon');
    // submit the form
    $this->getSession()->getPage()->pressButton('Save configuration');
    // check if the error message is shown
    $this->assertSession()->pageTextContains('field is required');
  }

}
